#
# spec file for package redshift
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           redshift
Version:        1.12
Release:        9.1
Summary:        Tool for adjusting the color temperature of the screen
License:        GPL-3.0-only
Group:          System/X11/Utilities
URL:            http://jonls.dk/redshift/
Source:         https://github.com/jonls/redshift/releases/download/v%{version}/%{name}-%{version}.tar.xz
Patch0:         desktop.patch
# PATCH-FIX-OPENSUSE Update py-compile to support Python 3.13, regenerated by autoreconf
Patch1:         update-py-compile.patch
BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(geoclue-2.0)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xxf86vm)
Recommends:     geoclue2
%{?systemd_requires}

%description
Redshift adjusts the color temperature of the screen according to time.
This may help easing eyestrain when working at night.
Time-independent manual operation and individual gamma curve
setting is possible as well.

%package gtk
Summary:        Gtk frontend for redshift
Group:          System/X11/Utilities
Requires:       %{name} = %{version}-%{release}
Requires:       hicolor-icon-theme
Recommends:     python3-pyxdg
%{?systemd_requires}
%if 0%{?sle_version} > 120100 || 0%{?suse_version} > 1320
Requires:       python3-gobject-Gdk
%else
Requires:       python3-gobject
%endif

%description gtk
A graphical user interface for the redshift tool that integrates into Gtk+ and GNOME.

%prep
%autosetup -p0

%build
%configure \
  --enable-apparmor \
  --enable-drm \
  --enable-gui \
  --enable-geoclue2 \
  --enable-randr \
  --enable-vidmode \
  --with-systemduserunitdir=%{_userunitdir}
%make_build

%install
%make_install
%fdupes -s %{buildroot}%{python3_sitelib}
%suse_update_desktop_file %{name}-gtk GTK X-SuSE-DesktopUtility
sed -i 's|/env python3|/python3|' %{buildroot}%{_bindir}/%{name}-gtk
mkdir %{buildroot}%{_sysconfdir}/apparmor.d/local
echo "# Site-specific additions and overrides for 'usr.bin.redshift'" \
  >%{buildroot}%{_sysconfdir}/apparmor.d/local/usr.bin.redshift

%find_lang %{name}

%post
%systemd_user_post %{name}.service

%preun
%systemd_user_preun %{name}.service

%post gtk
%systemd_user_post %{name}-gtk.service

%preun gtk
%systemd_user_preun %{name}-gtk.service

%files gtk -f %{name}.lang
%license COPYING
%{_bindir}/%{name}-gtk
%{python3_sitelib}/%{name}_gtk
%{_datadir}/applications/%{name}-gtk.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}-status-off.svg
%{_datadir}/icons/hicolor/scalable/apps/%{name}-status-on.svg
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_userunitdir}/%{name}-gtk.service
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}-gtk.appdata.xml

%files
%license COPYING
%doc README README-colorramp NEWS
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/applications/%{name}.desktop
%dir %{_sysconfdir}/apparmor.d/
%config %{_sysconfdir}/apparmor.d/usr.bin.redshift
%dir %{_sysconfdir}/apparmor.d/local/
%config(noreplace) %{_sysconfdir}/apparmor.d/local/usr.bin.redshift
%{_userunitdir}/%{name}.service

%changelog
* Wed Mar 12 2025 Steve Kowalik <steven.kowalik@suse.com>
- Add patch update-py-compile.patch:
  * Use autoreconf to regenerate py-compile script.
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Dec 14 2020 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- redshift-gtk require python-pyxdg, not incompatible python-xdg (boo#1179328)
  Downgrade to a Recommends since it only affects autostart installation
- Remove temporary apparmor profile fix (fix_apparmor.patch)
* Mon Jul 20 2020 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update apparmor profile to work around boo#1174290
* Wed Oct 17 2018 Ondřej Súkup <mimi.vx@gmail.com>
- fix apparmor profile - fix_apparmor.patch boo#1111906
* Sun Aug 26 2018 aaronpuchert@alice-dsl.net
- Move python3-xdg dependency to redshift-gtk.
  It's not needed for redshift itself, which is a pure C program.
- Don't require geoclue, only recommend it.
- Build and install AppArmor profile.
- desktop.patch: Do not start redshift in terminal window.
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrase in summary, and expand description.
* Sat Jun  2 2018 bjorn.lie@gmail.com
- Drop pkgconfig(gconf-2.0) BuildRequires: No longer needed, nor
  used.
* Mon May 28 2018 avindra@opensuse.org
- Change location providers to allow updates. GeoClue and CoreLocation
  now provide continuous location updates.
  - Removes deprecated original GeoClue location provider (use
  GeoClue 2 instead).
  - Allow time-based configuration i.e. setting the redness effect
  based on time of day instead of based on the elevation of the
  sun. See the man page for more information.
  - Config file moved to ~/.config/redshift/redshift.conf (or
  ${XDG_CONFIG_HOME}/redshift/redshift.conf) if $XDG_CONFIG_HOME is
  set. Old location at ~/.config/redshift.conf is deprecated but
  still searched as a fallback.
  - Run hooks when enabling/disabling Redshift.
  - Default temperatures changed to 6500K during daytime and 4500K
  during night.
  - With randr, allow multiple but not all CRTCs to be redshifted.
  - Option for enabling a short fade between color effects is now
  called `fade` instead of `transition` in the configuration file.
  Term transition caused a lot of confusion about what this option
  does (the old option still works but is deprecated).
  - The preserve option is enabled by default for vidmode, randr,
  Windows (w32gdi) and macOS (quartz). The option is now controlled
  by the -P command line option.
  - Work around issue where Windows adjustments sometimes fail.
  - Install AppArmor profile.
  - quartz: Fix incorrect use of display identifier.
  - Various bug fixes and updated translations.
* Wed Dec 13 2017 mimi.vx@gmail.com
- spec-cleaned, removed old code. @Mailender removed %%py_requires
* Mon May 15 2017 tejas.guruswamy@opensuse.org
- Remove conditions on unsupported suse versions, install systemd
  user service with redshift-gtk
* Thu Mar  9 2017 tejas.guruswamy@opensuse.org
- Add requires for typelib-1_0-AppIndicator3 for redshift-gtk
  (bsc#1024936)
* Wed May  4 2016 zaitor@opensuse.org
- Add explict Requires python-gobject-Gdk for gtk subpackage,
  needed after the spilt of python3-gobject.
- Drop autoconf and automake BuildRequires: They are not needed.
* Tue Apr  5 2016 dimstar@opensuse.org
- Run fdupes only over %%{python3_sitelib}, ensuring that the files
  in /usr/share/icons/hicolor remain actual files and cannot be
  accidentally converted to symlinks.
* Sun Feb  7 2016 mpluskal@suse.com
- Make building more verbose
- Update post/postun dependencies of -gtk subpackage
- Small spec file cleanups
- Fix building for Leap
* Tue Jan 19 2016 zaitor@opensuse.org
- Add pkgconfig(libdrm) BuildRequires: Build support for DRM
  adjustement method.
- Change --with-systemduserunitdir=no to
  - -with-systemduserunitdir=%%{_userunitdir} and package the
  produced service files. Users can do systemctl enable/disable
  - -user redshift.service or redshift-gtk.service depending on what
  package they install/want.
* Sat Jan 16 2016 mimi.vx@gmail.com
- update to 1.11
  * Add option preserve for gamma adjustment methods (randr, vidmode, quartz, w32gdi)
    to apply redness on top of current gamma correction.
  * Add redshift.desktop file to resolve an issue where Geoclue2 would not allow
    redshift to obtain the current location
  * Make sure that the child process is terminated when redshift-gtk exits.
  * A sample configuation file has been added to the distribution tarball.
  * Fix warning message in redshift-gtk that is some cases caused redshift-gtk to fail
  * Use nanosleep() for sleeping to avoid high CPU load on platforms (NetBSD, ...)
    with limitations in usleep()
  * Various updates to man page and translations.
* Fri Sep 11 2015 mimi.vx@gmail.com
- fix build on openSUSE:Leap
* Fri Feb 20 2015 mimi.vx@gmail.com
- spec-cleaned spec file
- use geoclue2 instead geoclue
- Update to 1.10
  * Fix #80: Add Geoclue2 location provider.
  * Add hooks for user actions on period switch.
  * Be less verbose when color values/period did not change.
  * Add config setting to set gamma separately for day/night.
  * Add support for custom transition start and end elevation (Mattias Andrée).
  * redshift-gtk: Show errors from child process in a dialog.
  * Fix #95: Add AppData file for package managers.
  * Fix #41: Do not jump to 0 %% or 100 %% when changing direction of transition (Mattias Andrée).
  * redshift-gtk: Relay USR1 signal to redshift process.
  * redshift-gtk: Notify desktop about startup completion.
  * Fix: systemd unit files were built from the wrong source.
  * Fix #90: Print N/S and E/W in the location (Mattias Andrée).
  * Fix #112: redshift-gtk: Do not buffer lines from child indefinitely.
  * Fix #105: Limit decimals in displayed location to two.
  * Update dependencies listed in HACKING.md (emilf, Kees Hink).
  * Fix: Make desktop file translatable.
* Mon Nov 24 2014 robert.munteanu@gmail.com
- Update to 1.9.1
  * Fix: Do not distribute redshift-gtk, only redshift-gtk.in.
  * Fix: Geoclue support should pull in Glib as dependency.
  * geoclue: Fix segfault when error is NULL (Mattias Andrée).
  * geoclue: Set DISPLAY=:0 to work around issue when outside X (Mattias Andrée).
  * redshift-gtk: Fix crash when toggling state using the status icon.
  * redshift-gtk: Fix line splitting logic (Maks Verver).
-  Update to 1.9
  * Use improved color scheme provided by Ingo Thies.
  * Add drm driver which will apply adjustments on linux consoles (Mattias Andrée).
  * Remove deprecated GNOME clock location provider.
  * Set proc title for redshift-gtk (Linux/BSD) (Philipp Hagemeister).
  * Show current temperature, location and status in GUI.
  * Add systemd user unit files so that redshift can be used with systemd as a session manager (Henry de Valence).
  * Use checkbox to toggle Redshift in GUI (Mattias Andrée).
  * Gamma correction is applied after brightness and temperature (Mattias Andrée).
  * Use XDG Base Directory Specification when looking for configuration file (Mattias Andrée).
  * Load config from %%LOCALAPPDATA%%\redshift.conf on Windows (TingPing).
  * Add RPM spec for Fedora in contrib.
  * redshift-gtk has been ported to Python3 and new PyGObject bindings for Python.
* Wed Nov 27 2013 mailaender@opensuse.org
- Separate GUI and CLI application into different packages
* Mon Nov 25 2013 mailaender@opensuse.org
- Add missing GeoClue build dependency
- Update to 1.8
  * IMPORTANT: gtk-redshift has changed name to redshift-gtk.
  * Fix crash when starting geoclue provider. (Thanks to Maks Verver)
  * Fix slight flicker int gamme ramp values (Sean Hildebrand)
  * Add redshift-gtk option to suspend for a short time period (Jendrik Seipp).
  * Add print mode (prints parameters and exits) by Vincent Breitmoser.
  * Set buffering on stdout and stderr to line-buffered.
  * Allow separate brightness for day and night (Olivier Fabre and Jeremy Erickson).
  * Fix various crashes/bugs/typos (Benjamin Kerensa and others)
* Sat Aug 13 2011 pascal.bleser@opensuse.org
- add missing Requires on python-xdg
* Wed Jul 20 2011 tejas.guruswamy@opensuse.org
- Update to 1.7
  * GeoClue location provider support
  * Allow brightness to be adjusted (-b).
  * Provide option to set color temperature directly (Joe Hillenbrand).
  * Add option to show program version (-V).
* Thu Dec 30 2010 tejas.guruswamy@opensuse.org
- Update to 1.6
  * Support for optional configuration file (fixes #590722).
  * Add man page for redshift written by Andrew Starr-Bochicchio (fixes #582196).
  * Explain in help output that 6500K is the neutral color temperature (fixes #627113).
  * Fix: Handle multiple instances of the GNOME clock applet; contributed by Francesco Marella (fixes #610860).
  * Fix: Redshift crashes when VidMode fails (fixes #657451).
  * Fix: Toggle menu item should not be of class gtk.ImageMenuItem (fixes #620355).
  * Application launcher and autostart feature contributed by Francesco Marella (fixes #590550, #612710).
  * Improve GNOME location provider (patch by Gabriel de Perthuis) (fixes #598277).
  * New ubuntu-mono-dark icons that fit the color guidelines better. Contributed by aleth (semi-fixes #596536).
  * Improve error message when first adjustment method fails (fixes #596537).
* Tue Jun 29 2010 ajorgensen@novell.com
- First version for SUSE (1.4.1)
